documentFactory.UrllibUnicodeFileThing

|  | ## Cheshire3 Object Model: Class UrllibUnicodeFileThing

Module documentFactory :: Class UrllibUnicodeFileThing

## Class UrllibUnicodeFileThing
source code

Instance Methods

__init__(self, real)
__getattr__(self, item)
read(self)

Method Details

### __init__(self, real) (Constructor) | source code

### __getattr__(self, item) (Qualification operator) | source code

### read(self) | source code